==> fastreeR_1.99.8.tar.gz: fastreeR/inst/NEWS.Rd <==
\name{fastreeRNews}
\title{fastreeR News}
\encoding{UTF-8}

\section{Version 1.99.8 (2025-10-22)}{\itemize{
\item Update backend (2.1.1) and CLI
}}



\section{Version 1.99.6 (2025-10-22)}{\itemize{
\item Update backend (2.1.0) and CLI
}}


\section{Version 1.99.0 (2025-05-29)}{\itemize{
\item Update backend and CLI. Preparing for major version upgrade
}}


\section{Version 1.13.30 (2025-05-18)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.29 (2025-05-18)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.27 (2025-05-17)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.26 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.25 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.24 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.23 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.22 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.21 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.20 (2025-05-14)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.19 (2025-05-14)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.1 (2025-04-11)}{\itemize{
\item Update backend and CLI
}}

\section{Version 1.7.3 (2024-04-07)}{\itemize{
\item Preparing for next Bioconductor Release
}}

\section{Version 1.7.2 (2024-02-10)}{\itemize{
\item Fix vignette bug
}}

\section{Version 1.7.1 (2024-02-10)}{\itemize{
\item Update R version requirement
}}

\section{Version 1.5.2 (2023-08-24)}{\itemize{
\item Update java backend to BioInfoJavaUtils-1.4.0 (haploid GT in vcf)
}}

\section{Version 1.5.1 (2023-04-30)}{\itemize{
\item Update java backend to BioInfoJavaUtils-1.3.1 (fasta header name)
}}

\section{Version 1.1.6 (2022-09-26)}{\itemize{
\item Update java backend to BioInfoJavaUtils-1.2.4 (revamped FastaManager)
}}

\section{Version 1.1.5 (2022-06-23)}{\itemize{
\item Update vignette minor bug
}}

\section{Version 1.1.4 (2022-06-16)}{\itemize{
\item Update vignette to handle getting sample files through https failure
}}

\section{Version 1.1.3 (2022-06-06)}{\itemize{
\item Update vignette to handle getting sample files through https failure
}}

\section{Version 1.1.2 (2022-05-15)}{\itemize{
\item Update possibly corrupted samples.vcf.gz
}}

\section{Version 1.1.1 (2022-05-08)}{\itemize{
\item Update tests to improve coverage
}}

\section{Version 1.0.0 (2022-04-27)}{\itemize{
\item Bioconductor 3.15 Release.
New package \pkg{fastreeR}, Phylogenetic, Distance
and Other Calculations on VCF and Fasta Files
}}

\section{Version 0.99.7 (2022-04-02)}{\itemize{
\item Updates and corrections after the 1st Bioconductor review
}}

\section{Version 0.99.6 (2022-03-26)}{\itemize{
\item Drop function \code{dist2hist}
}}

\section{Version 0.99.5 (2022-03-25)}{\itemize{
\item Update vignette's use of \code{dist2hist}
}}

\section{Version 0.99.4 (2022-03-25)}{\itemize{
\item Update java backend (createHistogram)
}}

\section{Version 0.99.3 (2022-03-25)}{\itemize{
\item Update java backend
}}

\section{Version 0.99.2 (2022-03-25)}{\itemize{
\item Update \code{README.md} to inform about JDK>=8 requirement
\item Update java dependencies (jfreechart-1.5.3)
}}

\section{Version 0.99.1 (2022-03-24)}{\itemize{
\item Update vignette to use \code{BiocFileCache}
so that sample vcf and fasta downloads not get repeated needlessly
}}

\section{Version 0.99.0 (2022-03-21)}{\itemize{
\item Submitted to Bioconductor
}}

==> fastreeR_1.99.10.tar.gz: fastreeR/inst/NEWS.Rd <==
\name{fastreeRNews}
\title{fastreeR News}
\encoding{UTF-8}


\section{Version 2.0.0 (2025-10-29)}{\itemize{
\item Implements streaming bootstrap; from VCF to newick with support values.
\item Streaming ultra-fast VCF processing; almost zero RAM needed.
\item Update backend (2.2.0) and CLI. Preparing for major version upgrade.
}}


\section{Version 1.99.0 (2025-05-29)}{\itemize{
\item Update backend and CLI. Preparing for major version upgrade
}}


\section{Version 1.13.30 (2025-05-18)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.29 (2025-05-18)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.27 (2025-05-17)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.26 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.25 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.24 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.23 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.22 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.21 (2025-05-16)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.20 (2025-05-14)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.19 (2025-05-14)}{\itemize{
\item Update backend and CLI
}}


\section{Version 1.13.1 (2025-04-11)}{\itemize{
\item Update backend and CLI
}}

\section{Version 1.7.3 (2024-04-07)}{\itemize{
\item Preparing for next Bioconductor Release
}}

\section{Version 1.7.2 (2024-02-10)}{\itemize{
\item Fix vignette bug
}}

\section{Version 1.7.1 (2024-02-10)}{\itemize{
\item Update R version requirement
}}

\section{Version 1.5.2 (2023-08-24)}{\itemize{
\item Update java backend to BioInfoJavaUtils-1.4.0 (haploid GT in vcf)
}}

\section{Version 1.5.1 (2023-04-30)}{\itemize{
\item Update java backend to BioInfoJavaUtils-1.3.1 (fasta header name)
}}

\section{Version 1.1.6 (2022-09-26)}{\itemize{
\item Update java backend to BioInfoJavaUtils-1.2.4 (revamped FastaManager)
}}

\section{Version 1.1.5 (2022-06-23)}{\itemize{
\item Update vignette minor bug
}}

\section{Version 1.1.4 (2022-06-16)}{\itemize{
\item Update vignette to handle getting sample files through https failure
}}

\section{Version 1.1.3 (2022-06-06)}{\itemize{
\item Update vignette to handle getting sample files through https failure
}}

\section{Version 1.1.2 (2022-05-15)}{\itemize{
\item Update possibly corrupted samples.vcf.gz
}}

\section{Version 1.1.1 (2022-05-08)}{\itemize{
\item Update tests to improve coverage
}}

\section{Version 1.0.0 (2022-04-27)}{\itemize{
\item Bioconductor 3.15 Release.
New package \pkg{fastreeR}, Phylogenetic, Distance
and Other Calculations on VCF and Fasta Files
}}

\section{Version 0.99.7 (2022-04-02)}{\itemize{
\item Updates and corrections after the 1st Bioconductor review
}}

\section{Version 0.99.6 (2022-03-26)}{\itemize{
\item Drop function \code{dist2hist}
}}

\section{Version 0.99.5 (2022-03-25)}{\itemize{
\item Update vignette's use of \code{dist2hist}
}}

\section{Version 0.99.4 (2022-03-25)}{\itemize{
\item Update java backend (createHistogram)
}}

\section{Version 0.99.3 (2022-03-25)}{\itemize{
\item Update java backend
}}

\section{Version 0.99.2 (2022-03-25)}{\itemize{
\item Update \code{README.md} to inform about JDK>=8 requirement
\item Update java dependencies (jfreechart-1.5.3)
}}

\section{Version 0.99.1 (2022-03-24)}{\itemize{
\item Update vignette to use \code{BiocFileCache}
so that sample vcf and fasta downloads not get repeated needlessly
}}

\section{Version 0.99.0 (2022-03-21)}{\itemize{
\item Submitted to Bioconductor
}}
